Gimmicks and hacks to make some of my other modules more robust and
less demanding of others.

*Latest release 20221228*:
Generalise the logging function map, add trace function, bugfix logging call lookup.

## Function `debug(*a, **kw)`

Wrapper for `debug()` which does a deferred import.

## Function `error(*a, **kw)`

Wrapper for `error()` which does a deferred import.

## Function `exception(*a, **kw)`

Wrapper for `exception()` which does a deferred import.

## Function `info(*a, **kw)`

Wrapper for `info()` which does a deferred import.

## Function `log(*a, **kw)`

Wrapper for `log()` which does a deferred import.

## Function `trace(*a, **kw)`

Wrapper for `info()` which does a deferred import.

## Function `warning(*a, **kw)`

Wrapper for `warning()` which does a deferred import.

# Release Log



*Release 20221228*:
Generalise the logging function map, add trace function, bugfix logging call lookup.

*Release 20220429*:
Add DEVNULL symbol, needed before Python 3.3.

*Release 20211208*:
Define TimeoutError.

*Release 20210306*:
Add simple implementations of nullcontext and SimpleNamespace.

*Release 20200418.1*:
Initial release with logging call stubs.
